# ========================================================================
#    This is a part of "gpop" - Gaussian output post processor
#            Copyright (c) 2002-2009 by A. Miyoshi, Univ. Tokyo
# ========================================================================

# --- make gpop - Gaussian output post processor -----------------------
#  gpop1scf: read Gaussian SCF-freq job output and create a .gpo file
#  gpop3atm: create .gpo data for atomic species
#  gpop3tst: modification of .gpo data for thermo and TST calculations
#   gpop3mod: (under construction) forth-coming version of gpop3tst
#  gpop4thf: calculate thermodynamic functions
#  gpop5vib: create animation file (for FreeWheel) of vibrational modes
#  gpop6irt: calculate reduced moment of inertia of a internal rotor
#  tstrate: TST rate constant and equilibrium const. calculation
# ----------------------------------------------------------------------

# ----- names of C++ and Fortran compilers and options -----------------
# ----- suggested names of C++ and Fortran compilers
#  GNU compiler (Linux, Cygwin)     .. g++, g77
#               (Djgpp)             .. gpp, g77
#  Intel compilers for Linus        .. icc, ifort
#                  for Windows      .. icl, ifort
#  Unix (Solaris)                   .. CC,  f77
# ----- suggested optimization flags
#  Intel compilers for Windows      .. -O2
#  Others                           .. -O
# ----------------------------------------------------------------------

#CPCMP = g++ -O
#CPCMP = gpp -O
CPCMP = icc -O
#CPCMP = icl -O2
#CPCMP = CC -O

#F7CMP = g77 -O
F7CMP = ifort -O
#F7CMP = ifort -O2
#F7CMP = f77 -O

# ----- name of the LAPACK/BLAS library file ---------------------------
#  to build a part of LAPACK/BLAS:
#   Intel compilers for Windows     .. lapack_dsyev.lib
#   all other                       .. lapack_dsyev.a
#  use pre-build LAPACK/BLAS:       .. (null)
# ----------------------------------------------------------------------

FLPKSE = lapack_dsyev.a
#FLPKSE = lapack_dsyev.lib
#FLPKSE =

# ----- program to be used for linking ---------------------------------

#LNKER = $(CPCMP)
LNKER = $(F7CMP) -nofor_main

# ----- library options to the linker ----------------------------------
#  when FLPKSE != (null)
#   GNU compiler                    .. -lg2c
#   Intel compilers for Linux       .. -cxxlib
#   Intel compiler for Windows      .. (null)
#   Unix (Solaris)                  .. -lfsu -lsunmath
#  when FLPKSE == (null)
#   linux g77-built BLAS/LAPACK     .. -llapack -lblas -lg2c
#   intel MKL                       .. (consult the MKL manual)
# ----------------------------------------------------------------------

#LLIBS = -lg2c
LLIBS = -cxxlib
#LLIBS =
#LLIBS = -lfsu -lsunmath
#LLIBS = -llapack -lblas -lg2c

# ----- 'remove' command -----------------------------------------------

RM = rm -f
#RM = del

# ----- file name extension of object files ----------------------------

XOBJ = o
#XOBJ = obj

# ----- temporary files other than object file -------------------------
# (usually needed ONLY for Djgpp)

#TMPF = gpop1scf gpop3atm gpop3tst gpop3mod gpop4thf gpop5vib gpop6irt gpop6mrt gpop7ctr tstrate vtst introt prepum
TMPF =

# ===== no need to edit below in usual circumstances =====================

LIBOBJ = gpoplibc.$(XOBJ) gpoplibf.$(XOBJ) $(FLPKSE)
LIBROBJ = gpoplibr.$(XOBJ) $(LIBOBJ)
LIBTOBJ = gpoplibt.$(XOBJ) $(LIBROBJ)
LIBUOBJ = gpoplibu.$(XOBJ) $(LIBTOBJ)
HEADS = gpoplibc.h gpoplibf.h
HEADSR = gpoplibr.h $(HEADS)
HEADST = gpoplibt.h $(HEADSR)
HEADSU = gpoplibu.h $(HEADST)

all: gpop1scf gpop3atm gpop3tst gpop4thf gpop5vib \
     gpop6irt gpop6mrt tstrate vtst introt prepum

gpop1scf : gpop1scf.$(XOBJ) $(LIBOBJ)
	$(LNKER) gpop1scf.$(XOBJ) $(LIBOBJ) $(LLIBS) -o gpop1scf

gpop3atm : gpop3atm.$(XOBJ) $(LIBTOBJ)
	$(LNKER) gpop3atm.$(XOBJ) $(LIBTOBJ) $(LLIBS) -o gpop3atm

gpop3tst : gpop3tst.$(XOBJ) $(LIBTOBJ)
	$(LNKER) gpop3tst.$(XOBJ) $(LIBTOBJ) $(LLIBS) -o gpop3tst

gpop3mod : gpop3mod.$(XOBJ) $(LIBTOBJ)
	$(LNKER) gpop3mod.$(XOBJ) $(LIBTOBJ) $(LLIBS) -o gpop3mod

gpop4thf : gpop4thf.$(XOBJ) $(LIBTOBJ)
	$(LNKER) gpop4thf.$(XOBJ) $(LIBTOBJ) $(LLIBS) -o gpop4thf

gpop5vib : gpop5vib.$(XOBJ) $(LIBOBJ)
	$(LNKER) gpop5vib.$(XOBJ) $(LIBOBJ) $(LLIBS) -o gpop5vib

gpop6irt : gpop6irt.$(XOBJ) $(LIBOBJ)
	$(LNKER) gpop6irt.$(XOBJ) $(LIBOBJ) $(LLIBS) -o gpop6irt

gpop6mrt : gpop6mrt.$(XOBJ) $(LIBROBJ)
	$(LNKER) gpop6mrt.$(XOBJ) $(LIBROBJ) $(LLIBS) -o gpop6mrt

gpop7ctr : gpop7ctr.$(XOBJ) $(LIBOBJ)
	$(LNKER) gpop7ctr.$(XOBJ) $(LIBOBJ) $(LLIBS) -o gpop7ctr

tstrate : tstrate.$(XOBJ) $(LIBTOBJ)
	$(LNKER) tstrate.$(XOBJ) $(LIBTOBJ) $(LLIBS) -o tstrate

vtst : vtst.$(XOBJ) $(LIBTOBJ) spline.$(XOBJ)
	$(LNKER) vtst.$(XOBJ) $(LIBTOBJ) spline.$(XOBJ) $(LLIBS) -o vtst

introt : introt.$(XOBJ) $(LIBTOBJ)
	$(LNKER) introt.$(XOBJ) $(LIBTOBJ) $(LLIBS) -o introt

prepum : prepum.$(XOBJ) $(LIBUOBJ)
	$(LNKER) prepum.$(XOBJ) $(LIBUOBJ) $(LLIBS) -o prepum

gpop1scf.$(XOBJ) : gpop1scf.cc gpop1scf.h $(HEADS)
	$(CPCMP) -c gpop1scf.cc

gpop3atm.$(XOBJ) : gpop3atm.cc $(HEADST)
	$(CPCMP) -c gpop3atm.cc

gpop3tst.$(XOBJ) : gpop3tst.cc $(HEADST)
	$(CPCMP) -c gpop3tst.cc

gpop3mod.$(XOBJ) : gpop3mod.cc $(HEADST)
	$(CPCMP) -c gpop3mod.cc

gpop4thf.$(XOBJ) : gpop4thf.cc $(HEADST)
	$(CPCMP) -c gpop4thf.cc

gpop5vib.$(XOBJ) : gpop5vib.cc $(HEADS)
	$(CPCMP) -c gpop5vib.cc

gpop6irt.$(XOBJ) : gpop6irt.cc $(HEADS)
	$(CPCMP) -c gpop6irt.cc

gpop6mrt.$(XOBJ) : gpop6mrt.cc $(HEADSR)
	$(CPCMP) -c gpop6mrt.cc

gpop7ctr.$(XOBJ) : gpop7ctr.cc $(HEADS)
	$(CPCMP) -c gpop7ctr.cc

tstrate.$(XOBJ) : tstrate.cc $(HEADST)
	$(CPCMP) -c tstrate.cc

vtst.$(XOBJ) : vtst.cc vtst.h spline.h $(HEADST)
	$(CPCMP) -c vtst.cc

introt.$(XOBJ) : introt.cc $(HEADST)
	$(CPCMP) -c introt.cc

prepum.$(XOBJ) : prepum.cc $(HEADSU)
	$(CPCMP) -c prepum.cc

gpoplibu.$(XOBJ) : gpoplibu.cc $(HEADSU)
	$(CPCMP) -c gpoplibu.cc

gpoplibt.$(XOBJ) : gpoplibt.cc $(HEADST)
	$(CPCMP) -c gpoplibt.cc

gpoplibr.$(XOBJ) : gpoplibr.cc $(HEADSR)
	$(CPCMP) -c gpoplibr.cc

gpoplibc.$(XOBJ) : gpoplibc.cc $(HEADS)
	$(CPCMP) -c gpoplibc.cc

gpoplibf.$(XOBJ) : gpoplibf.cc gpoplibf.h
	$(CPCMP) -c gpoplibf.cc

spline.$(XOBJ) : spline.cc spline.h
	$(CPCMP) -c spline.cc

lapack_dsyev.a : lapack_dsyev/*.f
	cd lapack_dsyev; \
	$(F7CMP) -c *.f; \
	ar cr ../$(FLPKSE) *.$(XOBJ); \
	$(RM) *.$(XOBJ); \
	cd ..

lapack_dsyev.lib : lapack_dsyev/*.f
	cd lapack_dsyev
	$(F7CMP) -c *.f
	lib /OUT:..\$(FLPKSE) *.$(XOBJ)
	$(RM) *.$(XOBJ)
	cd ..

clean:
	$(RM) *.$(XOBJ) $(FLPKSE) $(TMPF)

