/*========================================================================
     "prepum"  preparation of UNIMOL input from gpop files
             Copyright (c) 2002-2009 by A. Miyoshi, Univ. Tokyo
                                     created: Aug.  11, 2009
                                 last edited: Oct.  24, 2009
--------------------------------------------------------------------------
 usage: prepum basename
--------------------------------------------------------------------------
 - Read basename.um file.  Also reads .gpo files specified
    in the basename.um file.
 - UNIMOL input file is generated in basename_rrkm.inp file
 - Keywords allowed in .um file are:
    title title_string(s)  ! title for UNIMOL input file
    energyUnit uStr(s)     ! "hartree" (default), "kJ/mol", or "cm-1"
    grainSize gsize(int)
    alignBaseEnergy aBaseE(double)
    tempRange Tstart(double) Tend(double) Tstep(double)
    tempRecipRange numer(double) start(double) end(double) step(double)
    tempList T1(double) T2(double) ...
    bufferByName name
    buffer molW sigma epsK
    collMolec sigma epsK
    collPair sigma epsK
    reactant{
      file fRe(s)
      energy eRe(double)
    }
    channel{
      transitionState{
        file fTS(s)
        energy eTS(double)
        imagFreqTS imfrq(double)
      }
      products{
        file f1Pr(s) [f2Pr(s) ...]
        energy ePr(double)
      }
    }
========================================================================*/

#include "gpoplibu.h"

/*===== main function ==================================================*/

int main(int argc, char *argv[]) {
  string basfln;
  rrkmInfo rrkm;

  showRevision();
  if (argc != 2) { cout << "usage: prepum basename\n"; return 1; }
  basfln = argv[1];
  if (rrkm.readFrom(basfln) == ERRE)
    { cout << "Error reading [" << basfln << ".um].\n"; return 1; }
  if (rrkm.readProp() == ERRE)
    { cout << "Error reading properties.\n"; return 1; }
  rrkm.outRRKM(basfln);
  return 0;
}

